==> varx_design_system-0.2.1.tar.gz: lib/themes/varx_theme.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:varx_design_system/themes/varx_color.dart';

class VarxTheme {
  static AppBarTheme appbarTHeme = const AppBarTheme(
    elevation: 1,
    systemOverlayStyle: SystemUiOverlayStyle(
      statusBarColor: Colors.transparent,
      statusBarIconBrightness: Brightness.light,
      statusBarBrightness: Brightness.dark,
      systemNavigationBarColor: Colors.transparent,
      systemNavigationBarIconBrightness: Brightness.light,
    ),
  );

  static final inputDecorationTheme = InputDecorationTheme(
    filled: true,
    contentPadding: const EdgeInsets.symmetric(vertical: 15, horizontal: 15),
    border: OutlineInputBorder(
      borderRadius: BorderRadius.circular(8),
    ),
    enabledBorder: OutlineInputBorder(
      borderSide: const BorderSide(color: VarxColor.neutral80),
      borderRadius: BorderRadius.circular(8),
    ),
    focusedBorder: OutlineInputBorder(
      borderRadius: BorderRadius.circular(8),
    ),
    alignLabelWithHint: true,
    errorBorder: OutlineInputBorder(
      borderRadius: BorderRadius.circular(8),
      borderSide: const BorderSide(color: VarxColor.error),
    ),
    focusedErrorBorder: OutlineInputBorder(
      borderRadius: BorderRadius.circular(8),
      borderSide: const BorderSide(color: VarxColor.error),
    ),
    hintStyle: const TextStyle(color: Colors.grey),
  );

  static final inputDecorationDarkTheme = inputDecorationTheme.copyWith(
    focusedBorder: OutlineInputBorder(
      borderRadius: BorderRadius.circular(8),
    ),
    errorBorder: OutlineInputBorder(
      borderRadius: BorderRadius.circular(8),
      borderSide: const BorderSide(color: VarxColor.darkError),
    ),
    focusedErrorBorder: OutlineInputBorder(
      borderRadius: BorderRadius.circular(8),
      borderSide: const BorderSide(color: VarxColor.darkError),
    ),
    errorStyle: const TextStyle(
      color: VarxColor.darkError,
    ),
  );

  static final elevatedButtonTheme = ElevatedButtonThemeData(
    style: ElevatedButton.styleFrom(
      elevation: 0,
      padding: const EdgeInsets.symmetric(horizontal: 16, vertical: 14),
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(8),
      ),
    ),
  );

  static final outlinedButtonTheme = OutlinedButtonThemeData(
    style: OutlinedButton.styleFrom(
      padding: const EdgeInsets.symmetric(horizontal: 16, vertical: 14),
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(8),
      ),
    ),
  );

  static final outlinedButtonThemeDark = OutlinedButtonThemeData(
    style: OutlinedButton.styleFrom(
      padding: const EdgeInsets.symmetric(horizontal: 16, vertical: 14),
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(8),
      ),
    ),
  );

  static final textButtonTheme = TextButtonThemeData(
    style: TextButton.styleFrom(
      padding: const EdgeInsets.symmetric(horizontal: 16, vertical: 14),
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(8),
      ),
    ),
  );

  static final cardTheme = CardTheme(
    margin: const EdgeInsets.only(bottom: 10),
    elevation: 6,
    shape: RoundedRectangleBorder(
      borderRadius: BorderRadius.circular(10),
    ),
  );

  static ThemeData light(Color? primary, TextTheme? textTheme) {
    final lightTheme = ThemeData(
      visualDensity: VisualDensity.adaptivePlatformDensity,
      brightness: Brightness.light,
      colorScheme: ColorScheme.fromSeed(
        seedColor: primary ?? const Color(0xFF1D5BB9),
      ),
      useMaterial3: true,
      textTheme: textTheme,
      disabledColor: Colors.grey,
      hintColor: Colors.grey,
      appBarTheme: appbarTHeme,
      inputDecorationTheme: inputDecorationTheme,
      iconTheme: const IconThemeData(
        color: Colors.black54,
      ),
      cardTheme: cardTheme,
      elevatedButtonTheme: elevatedButtonTheme,
      outlinedButtonTheme: outlinedButtonTheme,
      buttonTheme: ButtonThemeData(
        buttonColor: primary,
        disabledColor: Colors.grey,
        splashColor: Colors.white,
      ),
      textButtonTheme: textButtonTheme,
      dividerColor: const Color(0xFFDBE2F9),
      dividerTheme: const DividerThemeData(thickness: 1),
      listTileTheme: const ListTileThemeData(
        horizontalTitleGap: 0,
      ),
    );

    return lightTheme;
  }

  static ThemeData dark(Color? primary, TextTheme? textTheme) {
    final darkTheme = ThemeData(
      visualDensity: VisualDensity.adaptivePlatformDensity,
      scaffoldBackgroundColor: Colors.grey[900],
      brightness: Brightness.dark,
      colorScheme: ColorScheme.fromSeed(
        seedColor: primary ?? const Color(0xFF1D5BB9),
        brightness: Brightness.dark,
      ),
      useMaterial3: true,
      textTheme: textTheme,
      hintColor: Colors.grey,
      appBarTheme: appbarTHeme.copyWith(
        systemOverlayStyle: const SystemUiOverlayStyle(
          statusBarColor: Colors.transparent,
          statusBarIconBrightness: Brightness.light,
          statusBarBrightness: Brightness.dark,
          systemNavigationBarIconBrightness: Brightness.light,
        ),
        color: Colors.grey[900],
      ),
      inputDecorationTheme: inputDecorationDarkTheme,
      cardTheme: cardTheme,
      elevatedButtonTheme: elevatedButtonTheme,
      outlinedButtonTheme: outlinedButtonThemeDark,
      buttonTheme: const ButtonThemeData(
        disabledColor: Colors.grey,
        splashColor: Colors.white,
      ),
      textButtonTheme: textButtonTheme,
      dividerTheme: const DividerThemeData(thickness: 1),
      listTileTheme: const ListTileThemeData(
        horizontalTitleGap: 0,
      ),
    );

    return darkTheme;
  }
}

==> varx_design_system-0.2.4.tar.gz: lib/themes/varx_theme.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:varx_design_system/themes/varx_color.dart';

class VarxTheme {
  static AppBarTheme appbarTHeme = const AppBarTheme(
    elevation: 1,
    systemOverlayStyle: SystemUiOverlayStyle(
      statusBarColor: Colors.transparent,
      statusBarIconBrightness: Brightness.light,
      statusBarBrightness: Brightness.dark,
      systemNavigationBarColor: Colors.transparent,
      systemNavigationBarIconBrightness: Brightness.light,
    ),
  );

  static final inputDecorationTheme = InputDecorationTheme(
    filled: true,
    contentPadding: const EdgeInsets.symmetric(vertical: 15, horizontal: 15),
    border: OutlineInputBorder(
      borderRadius: BorderRadius.circular(8),
    ),
    enabledBorder: OutlineInputBorder(
      borderSide: const BorderSide(color: VarxColor.neutral80),
      borderRadius: BorderRadius.circular(8),
    ),
    focusedBorder: OutlineInputBorder(
      borderRadius: BorderRadius.circular(8),
    ),
    alignLabelWithHint: true,
    errorBorder: OutlineInputBorder(
      borderRadius: BorderRadius.circular(8),
      borderSide:  BorderSide(color: VarxColor.error),
    ),
    focusedErrorBorder: OutlineInputBorder(
      borderRadius: BorderRadius.circular(8),
      borderSide:  BorderSide(color: VarxColor.error),
    ),
    hintStyle: const TextStyle(color: Colors.grey),
  );

  static final inputDecorationDarkTheme = inputDecorationTheme.copyWith(
    focusedBorder: OutlineInputBorder(
      borderRadius: BorderRadius.circular(8),
    ),
    errorBorder: OutlineInputBorder(
      borderRadius: BorderRadius.circular(8),
      borderSide: const BorderSide(color: VarxColor.darkError),
    ),
    focusedErrorBorder: OutlineInputBorder(
      borderRadius: BorderRadius.circular(8),
      borderSide: const BorderSide(color: VarxColor.darkError),
    ),
    errorStyle: const TextStyle(
      color: VarxColor.darkError,
    ),
  );

  static final elevatedButtonTheme = ElevatedButtonThemeData(
    style: ElevatedButton.styleFrom(
      elevation: 0,
      padding: const EdgeInsets.symmetric(horizontal: 16, vertical: 14),
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(8),
      ),
    ),
  );

  static final elevatedButtonDarkTheme = ElevatedButtonThemeData(
    style: ElevatedButton.styleFrom(
      elevation: 0,
      padding: const EdgeInsets.symmetric(horizontal: 16, vertical: 14),
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(8),
      ),
    ),
  );

  static final outlinedButtonTheme = OutlinedButtonThemeData(
    style: OutlinedButton.styleFrom(
      padding: const EdgeInsets.symmetric(horizontal: 16, vertical: 14),
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(8),
      ),
    ),
  );

  static final outlinedButtonThemeDark = OutlinedButtonThemeData(
    style: OutlinedButton.styleFrom(
      padding: const EdgeInsets.symmetric(horizontal: 16, vertical: 14),
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(8),
      ),
    ),
  );

  static final textButtonTheme = TextButtonThemeData(
    style: TextButton.styleFrom(
      padding: const EdgeInsets.symmetric(horizontal: 16, vertical: 14),
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(8),
      ),
    ),
  );

  static final cardTheme = CardTheme(
    margin: const EdgeInsets.only(bottom: 10),
    elevation: 6,
    shape: RoundedRectangleBorder(
      borderRadius: BorderRadius.circular(10),
    ),
  );

  static ThemeData light(Color? primary, TextTheme? textTheme) {
    final lightTheme = ThemeData(
      visualDensity: VisualDensity.adaptivePlatformDensity,
      brightness: Brightness.light,
      colorScheme: ColorScheme.fromSeed(
        seedColor: primary ?? const Color(0xFF1D5BB9),
      ),
      useMaterial3: true,
      textTheme: textTheme,
      disabledColor: Colors.grey,
      hintColor: Colors.grey,
      appBarTheme: appbarTHeme,
      inputDecorationTheme: inputDecorationTheme,
      iconTheme: const IconThemeData(
        color: Colors.black54,
      ),
      cardTheme: cardTheme,
      elevatedButtonTheme: elevatedButtonTheme,
      outlinedButtonTheme: outlinedButtonTheme,
      buttonTheme: ButtonThemeData(
        buttonColor: primary,
        disabledColor: Colors.grey,
        splashColor: Colors.white,
      ),
      textButtonTheme: textButtonTheme,
      dividerColor: const Color(0xFFDBE2F9),
      dividerTheme: const DividerThemeData(thickness: 1),
      listTileTheme: const ListTileThemeData(
        horizontalTitleGap: 0,
      ),
    );

    return lightTheme;
  }

  static ThemeData dark(Color? primary, TextTheme? textTheme) {
    final darkTheme = ThemeData(
      visualDensity: VisualDensity.adaptivePlatformDensity,
      scaffoldBackgroundColor: Colors.grey[900],
      brightness: Brightness.dark,
      colorScheme: ColorScheme.fromSeed(
        seedColor: primary ?? const Color(0xFF1D5BB9),
        brightness: Brightness.dark,
      ),
      useMaterial3: true,
      textTheme: textTheme,
      hintColor: Colors.grey,
      appBarTheme: appbarTHeme.copyWith(
        systemOverlayStyle: const SystemUiOverlayStyle(
          statusBarColor: Colors.transparent,
          statusBarIconBrightness: Brightness.light,
          statusBarBrightness: Brightness.dark,
          systemNavigationBarIconBrightness: Brightness.light,
        ),
        color: Colors.grey[900],
      ),
      inputDecorationTheme: inputDecorationDarkTheme,
      cardTheme: cardTheme,
      elevatedButtonTheme: elevatedButtonTheme,
      outlinedButtonTheme: outlinedButtonThemeDark,
      buttonTheme: const ButtonThemeData(
        disabledColor: Colors.grey,
        splashColor: Colors.white,
      ),
      textButtonTheme: textButtonTheme,
      dividerTheme: const DividerThemeData(thickness: 1),
      listTileTheme: const ListTileThemeData(
        horizontalTitleGap: 0,
      ),
    );

    return darkTheme;
  }
}
